Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh	(revision 9220)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/sette_rpt.sh	(revision 9221)
@@ -184,4 +184,6 @@
     fi
     rm f1.tmp$$
+  else
+    printf "%-20s %s %s\n" $nam  " directory is MISSING : " $dorv
   fi
 }
@@ -273,4 +275,6 @@
       fi
     fi
+  else
+    printf "%-20s %s %s\n" $nam  " directory is MISSING : " $dorv
   fi
 }

Index: /branches/2017/dev_merge_2017/NEMOGCM/SETTE/new_sette_rpt.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/SETTE/new_sette_rpt.sh	(revision 9220)
+++ /branches/2017/dev_merge_2017/NEMOGCM/SETTE/new_sette_rpt.sh	(revision 9221)
@@ -106,8 +106,8 @@
     dorv=`echo $dorv | sed -e 's:.*/::'`
     f1o=$vdir/$nam/$mach/$dorv/LONG/ocean.output
-    f1s=$vdir/$nam/$mach/$dorv/LONG/solver.stat
+    f1s=$vdir/$nam/$mach/$dorv/LONG/run.stat
     f1t=$vdir/$nam/$mach/$dorv/LONG/tracer.stat
     f2o=$vdir/$nam/$mach/$dorv/SHORT/ocean.output
-    f2s=$vdir/$nam/$mach/$dorv/SHORT/solver.stat
+    f2s=$vdir/$nam/$mach/$dorv/SHORT/run.stat
     f2t=$vdir/$nam/$mach/$dorv/SHORT/tracer.stat
 
@@ -129,13 +129,13 @@
       if [ $? == 0 ]; then
         if [ $pass == 0 ]; then 
-          printf "%-20s %s %s\n" $nam  " solver.stat restartability  passed : " $dorv
+          printf "%-20s %s %s\n" $nam  " run.stat restartability  passed : " $dorv
         fi
       else
-        printf "%-20s %s %s\n" $nam  " solver.stat restartability  FAILED : " $dorv 
+        printf "%-20s %s %s\n" $nam  " run.stat restartability  FAILED : " $dorv 
 #
 # Offer view of differences on the second pass
 #
         if [ $pass == 1 ]; then
-          echo "<return> to view solver.stat differences"
+          echo "<return> to view run.stat differences"
           read y
           sdiff f1.tmp$$ $f2s
@@ -183,4 +183,6 @@
     fi
     rm f1.tmp$$
+  else
+    printf "%-20s %s %s\n" $nam  " directory is MISSING : " $dorv
   fi
 }
@@ -200,8 +202,8 @@
     rep2=`ls -1rt $vdir/$nam/$mach/$dorv/ | grep REPRO | tail -1l`
     f1o=$vdir/$nam/$mach/$dorv/$rep1/ocean.output
-    f1s=$vdir/$nam/$mach/$dorv/$rep1/solver.stat
+    f1s=$vdir/$nam/$mach/$dorv/$rep1/run.stat
     f1t=$vdir/$nam/$mach/$dorv/$rep1/tracer.stat
     f2o=$vdir/$nam/$mach/$dorv/$rep2/ocean.output
-    f2s=$vdir/$nam/$mach/$dorv/$rep2/solver.stat
+    f2s=$vdir/$nam/$mach/$dorv/$rep2/run.stat
     f2t=$vdir/$nam/$mach/$dorv/$rep2/tracer.stat
 
@@ -221,13 +223,13 @@
       if [ $? == 0 ]; then 
         if [ $pass == 0 ]; then  
-          printf "%-20s %s %s\n" $nam  " solver.stat reproducibility passed : " $dorv
+          printf "%-20s %s %s\n" $nam  " run.stat reproducibility passed : " $dorv
         fi
       else
-        printf "%-20s %s %s\n" $nam  " solver.stat reproducibility FAILED : " $dorv
+        printf "%-20s %s %s\n" $nam  " run.stat reproducibility FAILED : " $dorv
 #
 # Offer view of differences on the second pass
 #
         if [ $pass == 1 ]; then
-          echo "<return> to view solver.stat differences"
+          echo "<return> to view run.stat differences"
           read y
           sdiff f1.tmp$$ $f2s
@@ -271,4 +273,6 @@
       fi
     fi
+  else
+    printf "%-20s %s %s\n" $nam  " directory is MISSING : " $dorv 
   fi
 }
@@ -277,5 +281,5 @@
 #
 #  checks AGRIF does not corrupe results with no AGRIF zoom. Expects ORCA2AGUL/AGRIFNOZ and ORCA2AGUL_NAGR/AGRIFNO  run directories
 # Compares solver.stat files for each
 #
   vdir=$1
@@ -292,6 +296,6 @@
     rep1=`ls -1rt $vdir/$dir1/$mach/$dorv1/ |  tail -2l | head -1 `
     rep2=`ls -1rt $vdir/$dir2/$mach/$dorv2/ |  tail -1l`
-    f1s=$vdir/$dir1/$mach/$dorv1/$rep1/solver.stat
-    f2s=$vdir/$dir2/$mach/$dorv2/$rep2/solver.stat
+    f1s=$vdir/$dir1/$mach/$dorv1/$rep1/run.stat
+    f2s=$vdir/$dir2/$mach/$dorv2/$rep2/run.stat
 
     if  [ ! -f $f1s ] && [ ! -f $f2s ] ; then 
@@ -306,13 +310,13 @@
       if [ $? == 0 ]; then
         if [ $pass == 0 ]; then 
-          printf "%-20s %s %s %s %s\n" $rep1 $rep2  " AGRIF: solver.stat unchanged - test  passed : " $dorv1 $dorv2
+          printf "%-20s %s %s %s %s\n" $rep1 $rep2  " AGRIF: run.stat unchanged - test  passed : " $dorv1 $dorv2
         fi
       else
-        printf "%-20s %s %s %s %s\n" $rep1 $rep2  " for AGRIF, solver.stat test FAILED : " $dorv1 $dorv2
+        printf "%-20s %s %s %s %s\n" $rep1 $rep2  " for AGRIF, run.stat test FAILED : " $dorv1 $dorv2
 #
 # Offer view of differences on the second pass
 #
         if [ $pass == 1 ]; then
-          echo "<return> to view solver.stat differences"
+          echo "<return> to view run.stat differences"
           read y
           sdiff $f1s $f2s
@@ -277,5 +281,5 @@
 #
 #  checks AGRIF does not corrupe results with no AGRIF zoom. Expects ORCA2AGUL/AGRIFNOZ and ORCA2AGUL_NAGR/AGRIFNO  run directories
-# Compares solver.stat files for each
+# Compares run.stat files for each
 #
   vdir=$1